@@ -150,10 +150,8 @@ static gint
 toggle_button_toggled_cb(GtkToggleButton *button, gpointer data)
 {
   charpick_data *curr_data = data;
-  gint button_index;
   gboolean toggled;
-   
-  button_index = GPOINTER_TO_INT (g_object_get_data (G_OBJECT (button), "index")); 
+
   toggled = gtk_toggle_button_get_active (button); 
 
   if (toggled)
@@ -174,29 +172,11 @@ toggle_button_toggled_cb(GtkToggleButton *button, gpointer data)
     gtk_selection_owner_set (curr_data->applet,
 	  		     GDK_SELECTION_CLIPBOARD,
                              GDK_CURRENT_TIME); 
-    curr_data->last_index = button_index;
   }	
 	     
   return TRUE;
 }
 
-/* This is a hack around the fact that gtk+ doesn't
- * propogate button presses on button2/3.
- */
-static gboolean
-button_press_hack (GtkWidget      *widget,
-		   GdkEventButton *event,
-		   GtkWidget      *applet)
-{
-    if (event->button == 3 || event->button == 2) {
-	gtk_propagate_event (applet, (GdkEvent *) event);
-
-	return TRUE;
-    }
-
-    return FALSE;
-}
-
 static gint
 key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
 {
@@ -261,7 +241,6 @@ key_press_event(GtkWidget *widget, GdkEventKey *event, gpointer data)
     p_curr_data->charlist = g_ucs4_to_utf8 (code, -1, NULL, NULL, NULL);
   else
     p_curr_data->charlist = "hello";
-  p_curr_data->last_index = NO_LAST_INDEX;
   p_curr_data->last_toggle_button = NULL;
   build_table(p_curr_data);
 #endif
@@ -426,10 +405,6 @@ build_table(charpick_data *p_curr_data)
     g_signal_connect (G_OBJECT (button), "clicked",
                               G_CALLBACK (chooser_button_clicked),
 			      p_curr_data);
-    g_signal_connect (G_OBJECT (button), "button_press_event",
-                               G_CALLBACK (button_press_hack),
-			       p_curr_data->applet);
-  
   }
   
   charlist = g_strdup (p_curr_data->charlist);
@@ -474,8 +449,6 @@ build_table(charpick_data *p_curr_data)
     g_signal_connect (G_OBJECT (toggle_button[i]), "toggled",
 		      G_CALLBACK (toggle_button_toggled_cb),
                         p_curr_data);
-    g_signal_connect (G_OBJECT (toggle_button[i]), "button_press_event", 
-                      G_CALLBACK (button_press_hack), p_curr_data->applet);
   }
   
   if (p_curr_data->panel_vertical) {
@@ -515,9 +488,7 @@ build_table(charpick_data *p_curr_data)
   gtk_container_add (GTK_CONTAINER(p_curr_data->applet), box);
   gtk_widget_show_all (p_curr_data->box);
 
-  p_curr_data->last_index = NO_LAST_INDEX;
   p_curr_data->last_toggle_button = NULL;
-  
 }
 
 static void applet_size_allocate(PanelApplet *applet, GtkAllocation *allocation, gpointer data)
@@ -591,7 +562,7 @@ help_cb (GSimpleAction *action,
   GError *error = NULL;
 
   gtk_show_uri (gtk_widget_get_screen (GTK_WIDGET (curr_data->applet)),
-                "ghelp:char-palette",
+                "help:char-palette",
                 gtk_get_current_event_time (),
                 &error);
 
@@ -706,7 +677,6 @@ charpicker_applet_fill (PanelApplet *applet)
   panel_applet_set_flags (applet, PANEL_APPLET_EXPAND_MINOR);
    
   curr_data = g_new0 (charpick_data, 1);
-  curr_data->last_index = NO_LAST_INDEX;
   curr_data->applet = GTK_WIDGET (applet);
   curr_data->about_dialog = NULL;
   curr_data->add_edit_dialog = NULL;
